Module blaxel.core.client.models.entrypoint
===========================================

Classes
-------

`Entrypoint(args: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, command: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, env: blaxel.core.client.types.Unset | ForwardRef('EntrypointEnv') = <blaxel.core.client.types.Unset object>)`
:   Entrypoint of the artifact
    
    Attributes:
        args (Union[Unset, list[Any]]): Args of the entrypoint
        command (Union[Unset, str]): Command of the entrypoint
        env (Union[Unset, EntrypointEnv]): Env of the entrypoint
    
    Method generated by attrs for class Entrypoint.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `args`
    :

    `command`
    :

    `env`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :